==> esmvalcore-2.11.0rc1.tar.gz: esmvalcore-2.11.0rc1/tests/integration/cmor/_fixes/cmip6/test_bcc_esm1.py <==
"""Test fixes for BCC-ESM1."""
from esmvalcore.cmor._fixes.cmip6.bcc_esm1 import (
    Cl,
    Cli,
    Clw,
    Siconc,
    So,
    Sos,
    Tos,
)
from esmvalcore.cmor._fixes.common import (
    ClFixHybridPressureCoord,
    OceanFixGrid,
)
from esmvalcore.cmor._fixes.fix import Fix, GenericFix


def test_get_cl_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Amon', 'cl')
    assert fix == [Cl(None), GenericFix(None)]


def test_cl_fix():
    """Test fix for ``cl``."""
    assert Cl is ClFixHybridPressureCoord


def test_get_cli_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Amon', 'cli')
    assert fix == [Cli(None), GenericFix(None)]


def test_cli_fix():
    """Test fix for ``cli``."""
    assert Cli is ClFixHybridPressureCoord


def test_get_clw_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Amon', 'clw')
    assert fix == [Clw(None), GenericFix(None)]


def test_clw_fix():
    """Test fix for ``clw``."""
    assert Clw is ClFixHybridPressureCoord


def test_get_siconc_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'SImon', 'siconc')
    assert fix == [Siconc(None), GenericFix(None)]


def test_siconc_fix():
    """Test fix for ``siconc``."""
    assert Siconc is OceanFixGrid


def test_get_so_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Omon', 'so')
    assert fix == [So(None), GenericFix(None)]


def test_so_fix():
    """Test fix for ``so``."""
    assert So is OceanFixGrid


def test_get_sos_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Omon', 'sos')
    assert fix == [Sos(None), GenericFix(None)]


def test_sos_fix():
    """Test fix for ``sos``."""
    assert Sos is OceanFixGrid


def test_get_tos_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes('CMIP6', 'BCC-ESM1', 'Omon', 'tos')
    assert fix == [Tos(None), GenericFix(None)]


def test_tos_fix():
    """Test fix for ``tos``."""
    assert Tos is OceanFixGrid

==> esmvalcore-2.12.0rc2.tar.gz: esmvalcore-2.12.0rc2/tests/integration/cmor/_fixes/cmip6/test_bcc_esm1.py <==
"""Test fixes for BCC-ESM1."""

from esmvalcore.cmor._fixes.cmip6.bcc_esm1 import (
    Cl,
    Cli,
    Clw,
    Siconc,
    So,
    Sos,
    Tos,
)
from esmvalcore.cmor._fixes.common import (
    ClFixHybridPressureCoord,
    OceanFixGrid,
)
from esmvalcore.cmor._fixes.fix import Fix, GenericFix


def test_get_cl_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Amon", "cl")
    assert fix == [Cl(None), GenericFix(None)]


def test_cl_fix():
    """Test fix for ``cl``."""
    assert Cl is ClFixHybridPressureCoord


def test_get_cli_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Amon", "cli")
    assert fix == [Cli(None), GenericFix(None)]


def test_cli_fix():
    """Test fix for ``cli``."""
    assert Cli is ClFixHybridPressureCoord


def test_get_clw_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Amon", "clw")
    assert fix == [Clw(None), GenericFix(None)]


def test_clw_fix():
    """Test fix for ``clw``."""
    assert Clw is ClFixHybridPressureCoord


def test_get_siconc_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "SImon", "siconc")
    assert fix == [Siconc(None), GenericFix(None)]


def test_siconc_fix():
    """Test fix for ``siconc``."""
    assert Siconc is OceanFixGrid


def test_get_so_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Omon", "so")
    assert fix == [So(None), GenericFix(None)]


def test_so_fix():
    """Test fix for ``so``."""
    assert So is OceanFixGrid


def test_get_sos_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Omon", "sos")
    assert fix == [Sos(None), GenericFix(None)]


def test_sos_fix():
    """Test fix for ``sos``."""
    assert Sos is OceanFixGrid


def test_get_tos_fix():
    """Test getting of fix."""
    fix = Fix.get_fixes("CMIP6", "BCC-ESM1", "Omon", "tos")
    assert fix == [Tos(None), GenericFix(None)]


def test_tos_fix():
    """Test fix for ``tos``."""
    assert Tos is OceanFixGrid
